@@ -8,6 +8,7 @@ use std::mem;
 use std::ptr;
 use std::str;
 
+#[doc(alias = "GST_VIDEO_MAX_PLANES")]
 pub const VIDEO_MAX_PLANES: usize = ffi::GST_VIDEO_MAX_PLANES as usize;
 
 #[derive(Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Clone, Copy)]
@@ -83,6 +84,7 @@ impl ToValue for VideoColorRange {
 }
 
 #[doc(alias = "GstVideoColorimetry")]
+#[derive(Copy, Clone)]
 pub struct VideoColorimetry(ffi::GstVideoColorimetry);
 
 impl VideoColorimetry {
@@ -121,12 +123,6 @@ impl VideoColorimetry {
     }
 }
 
-impl Clone for VideoColorimetry {
-    fn clone(&self) -> Self {
-        unsafe { Self(ptr::read(&self.0)) }
-    }
-}
-
 impl PartialEq for VideoColorimetry {
     #[doc(alias = "gst_video_colorimetry_is_equal")]
     fn eq(&self, other: &Self) -> bool {
@@ -227,7 +223,7 @@ impl From<crate::VideoMultiviewFramePacking> for crate::VideoMultiviewMode {
     }
 }
 
-impl std::convert::TryFrom<crate::VideoMultiviewMode> for crate::VideoMultiviewFramePacking {
+impl TryFrom<crate::VideoMultiviewMode> for crate::VideoMultiviewFramePacking {
     type Error = glib::BoolError;
 
     fn try_from(v: crate::VideoMultiviewMode) -> Result<Self, glib::BoolError> {
@@ -244,6 +240,7 @@ impl std::convert::TryFrom<crate::VideoMultiviewMode> for crate::VideoMultiviewF
 }
 
 #[doc(alias = "GstVideoInfo")]
+#[derive(Clone)]
 pub struct VideoInfo(pub(crate) ffi::GstVideoInfo);
 
 impl fmt::Debug for VideoInfo {
@@ -275,6 +272,7 @@ impl fmt::Debug for VideoInfo {
 }
 
 #[derive(Debug)]
+#[must_use = "The builder must be built to be used"]
 pub struct VideoInfoBuilder<'a> {
     format: crate::VideoFormat,
     width: u32,
@@ -404,13 +402,13 @@ impl<'a> VideoInfoBuilder<'a> {
             }
 
             if let Some(par) = self.par {
-                info.par_n = *par.numer();
-                info.par_d = *par.denom();
+                info.par_n = par.numer();
+                info.par_d = par.denom();
             }
 
             if let Some(fps) = self.fps {
-                info.fps_n = *fps.numer();
-                info.fps_d = *fps.denom();
+                info.fps_n = fps.numer();
+                info.fps_d = fps.denom();
             }
 
             if let Some(offset) = self.offset {
@@ -853,12 +851,6 @@ impl VideoInfo {
     }
 }
 
-impl Clone for VideoInfo {
-    fn clone(&self) -> Self {
-        unsafe { Self(ptr::read(&self.0)) }
-    }
-}
-
 impl PartialEq for VideoInfo {
     #[doc(alias = "gst_video_info_is_equal")]
     fn eq(&self, other: &Self) -> bool {
@@ -1068,19 +1060,16 @@ mod tests {
     fn test_from_to_caps() {
         gst::init().unwrap();
 
-        let caps = gst::Caps::new_simple(
-            "video/x-raw",
-            &[
-                ("format", &"I420"),
-                ("width", &320),
-                ("height", &240),
-                ("framerate", &gst::Fraction::new(30, 1)),
-                ("pixel-aspect-ratio", &gst::Fraction::new(1, 1)),
-                ("interlace-mode", &"progressive"),
-                ("chroma-site", &"mpeg2"),
-                ("colorimetry", &"bt709"),
-            ],
-        );
+        let caps = gst::Caps::builder("video/x-raw")
+            .field("format", "I420")
+            .field("width", 320)
+            .field("height", 240)
+            .field("framerate", gst::Fraction::new(30, 1))
+            .field("pixel-aspect-ratio", gst::Fraction::new(1, 1))
+            .field("interlace-mode", "progressive")
+            .field("chroma-site", "mpeg2")
+            .field("colorimetry", "bt709")
+            .build();
         let info = VideoInfo::from_caps(&caps).unwrap();
         assert_eq!(info.format(), crate::VideoFormat::I420);
         assert_eq!(info.width(), 320);
@@ -1135,11 +1124,9 @@ mod tests {
     #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_12")))]
     #[test]
     fn test_display() {
-        use std::str::FromStr;
-
         gst::init().unwrap();
 
-        format!("{}", crate::VideoColorimetry::from_str("sRGB").unwrap());
+        format!("{}", "sRGB".parse::<crate::VideoColorimetry>().unwrap());
         format!("{}", crate::VideoFieldOrder::TopFieldFirst);
         format!("{}", crate::VideoInterlaceMode::Progressive);
     }
